import re
from .rgb import RGBRenkler
import sys
from .utils import convert_color_to_ansi

TURKISH_COLORS_NAMES = {}

for color_name, color_value in RGBRenkler.__dict__.items():
    if not color_name.startswith("__"):
        TURKISH_COLORS_NAMES[color_name] = color_value

print(TURKISH_COLORS_NAMES)


def print(
    text: str,
    end: str | None = "\n",
) -> None:
    reset_escape = "\033[0m"

    # Handle color tags in the text
    pattern = re.compile(r"\[([^\[\]]+)\]")
    matches = pattern.finditer(text)

    for match in matches:
        color_tag = match.group(1)
        color = convert_color_to_ansi(color_tag)
        text = text.replace(f"[{color_tag}]", f"{color}", 1)

    sys.stdout.write(text + reset_escape + (end or ""))
    sys.stdout.flush()



class HEXRenkler:
    bordo = "#800000"
    koyu_kirmizi = "#8B0000"
    kahverengi = "#A52A2A"
    ates_tuglasi = "#B22222"
    kizil = "#DC143C"
    kirmizi = "#FF0000"
    domates = "#FF6347"
    mercan = "#FF7F50"
    hint_kirmizisi = "#CD5C5C"
    hafif_mercan = "#F08080"
    koyu_somon = "#E9967A"
    somon = "#FA8072"
    hafif_somon = "#FFA07A"
    turuncu_kirmizi = "#FF4500"
    koyu_turuncu = "#FF8C00"
    portakal = "#FFA500"
    altin = "#FFD700"
    koyu_altin_cubuk = "#B8860B"
    altin_cubuk = "#DAA520"
    soluk_altin_cubuk = "#EEE8AA"
    koyu_haki = "#BDB76B"
    haki = "#F0E68C"
    zeytin = "#808000"
    sari = "#FFFF00"
    sari_yesil = "#9ACD32"
    koyu_zeytin_yesili = "#556B2F"
    zeytin_yesili = "#6B8E23"
    yesil_cimen = "#7CFC00"
    grafigin_yeniden_kullanimi = "#7FFF00"
    yesil_sari = "#ADFF2F"
    koyu_yesil = "#006400"
    yesil = "#008000"
    orman_yesili = "#228B22"
    misket_limonu = "#00FF00"
    limon_yesili = "#32CD32"
    acik_yesil = "#90EE90"
    soluk_yesil = "#98FB98"
    koyu_deniz_yesili = "#8FBC8F"
    orta_bahar_yesili = "#00FA9A"
    ilkbahar_yesili = "#00FF7F"
    deniz_yesili = "#2E8B57"
    orta_su_denizi = "#66CDAA"
    orta_deniz_yesili = "#3CB371"
    acik_deniz_yesili = "#20B2AA"
    koyu_arduvaz_grisi = "#2F4F4F"
    camurcun = "#008080"
    koyu_camgobegi = "#008B8B"
    su = "#00FFFF"
    camgobegi = "#00FFFF"
    acik_cam_gobegi = "#E0FFFF"
    koyu_turkuaz = "#00CED1"
    turkuaz = "#40E0D0"
    orta_turkuaz = "#48D1CC"
    soluk_turkuaz = "#AFEEEE"
    aqua_marine = "#7FFFD4"
    toz_mavi = "#B0E0E6"
    harbiyeli_mavisi = "#5F9EA0"
    celik_mavisi = "#4682B4"
    misir_cicegi_mavisi = "#6495ED"
    derin_gok_mavisi = "#00BFFF"
    kacak_mavi = "#1E90FF"
    acik_mavi = "#ADD8E6"
    gokyuzu_mavi = "#87CEEB"
    acik_gok_mavisi = "#87CEFA"
    gece_yarisi_mavisi = "#191970"
    donanma = "#000080"
    koyu_mavi = "#00008B"
    orta_mavi = "#0000CD"
    mavi = "#0000FF"
    kraliyet_mavisi = "#4169E1"
    mavi_menekse = "#8A2BE2"
    civit = "#4B0082"
    koyu_barut_mavisi = "#483D8B"
    barut_mavisi = "#6A5ACD"
    orta_barut_mavisi = "#7B68EE"
    orta_mor = "#9370DB"
    koyu_macenta = "#8B008B"
    koyu_mor = "#9400D3"
    koyu_orkide = "#9932CC"
    orta_boy_orkide = "#BA55D3"
    mor = "#800080"
    devedikeni = "#D8BFD8"
    erik = "#DDA0DD"
    menekse = "#EE82EE"
    eflatun = "#FF00FF"
    orta_menekse_kirmizi = "#C71585"
    soluk_menekse_kirmizi = "#DB7093"
    derin_pembe = "#FF1493"
    sicak_pembe = "#FF69B4"
    acik_pembe = "#FFB6C1"
    pembe = "#FFC0CB"
    antik_beyaz = "#FAEBD7"
    bej = "#F5F5DC"
    bisque = "#FFE4C4"
    beyazlatilmis_badem = "#FFEBCD"
    bugday = "#F5DEB3"
    misir_puskulu = "#FFF8DC"
    limonlu_sifon = "#FFFACD"
    acik_altin_cubuk_sarisi = "#FAFAD2"
    acik_sari = "#FFFFE0"
    eyer_kahverengi = "#8B4513"
    sienna = "#A0522D"
    cikolata = "#D2691E"
    peru = "#CD853F"
    kumlu_kahverengi = "#F4A460"
    iri_odun = "#DEB887"
    bronzluk = "#D2B48C"
    pembe_kahverengi = "#BC8F8F"
    mokasen = "#FFE4B5"
    navajo_beyazi = "#FFDEAD"
    seftali_pufu = "#FFDAB9"
    puslu_gul = "#FFE4E1"
    lavanta_allik = "#FFF0F5"
    keten = "#FAF0E6"
    eski_dantel = "#FDF5E6"
    papaya_kirbaci = "#FFEFD5"
    deniz_kabugu = "#FFF5EE"
    nane_kremasi = "#F5FFFA"
    barut_grisi = "#708090"
    acik_barut_grisi = "#778899"
    acik_celik_mavisi = "#B0C4DE"
    lavanta = "#E6E6FA"
    cicek_beyazi = "#FFFAF0"
    alice_mavi = "#F0F8FF"
    hayalet_beyaz = "#F8F8FF"
    seker_kavunu = "#F0FFF0"
    fildisi = "#FFFFF0"
    gok_mavisi = "#F0FFFF"
    kar = "#FFFAFA"
    siyah = "#000000"
    soluk_gri = "#696969"
    gri = "#808080"
    koyu_gri = "#A9A9A9"
    gumus = "#C0C0C0"
    acik_gri = "#D3D3D3"
    gainsboro = "#DCDCDC"
    beyaz_duman = "#F5F5F5"
    beyaz = "#FFFFFF"



from .hex import HEXRenkler
from .rgb import RGBRenkler


def hex_to_rgb(hex_color: str) -> tuple[int, int, int]:
    hex_color = hex_color.lstrip("#")
    return tuple(int(hex_color[i : i + 2], 16) for i in (0, 2, 4))


def convert_color_to_ansi(color):
    if color is None:
        return ""

    if isinstance(color, tuple):  # RGB color
        red, green, blue = color
    elif isinstance(color, str):  # HEX color
        color = color.lower()
        if color in RGBRenkler.__dict__:
            red, green, blue = RGBRenkler.__dict__[color]
        elif color.startswith("#"):
            red, green, blue = hex_to_rgb(color)
        elif "," in color or isinstance(color, (list, tuple)):
            red, green, blue = map(int, color.split(","))
        else:
            raise ValueError("Invalid color value")

    # Convert RGB color to ANSI escape sequence
    return f"\033[38;2;{red};{green};{blue}m"



from pathlib import Path
from json import loads, dumps
from typing import Any, Callable, Optional, Union

from .text import Text
from .highlighter import JSONHighlighter, NullHighlighter


class JSON:
    """A renderable which pretty prints JSON.

    Args:
        json (str): JSON encoded data.
        indent (Union[None, int, str], optional): Number of characters to indent by. Defaults to 2.
        highlight (bool, optional): Enable highlighting. Defaults to True.
        skip_keys (bool, optional): Skip keys not of a basic type. Defaults to False.
        ensure_ascii (bool, optional): Escape all non-ascii characters. Defaults to False.
        check_circular (bool, optional): Check for circular references. Defaults to True.
        allow_nan (bool, optional): Allow NaN and Infinity values. Defaults to True.
        default (Callable, optional): A callable that converts values that can not be encoded
            in to something that can be JSON encoded. Defaults to None.
        sort_keys (bool, optional): Sort dictionary keys. Defaults to False.
    """

    def __init__(
        self,
        json: str,
        indent: Union[None, int, str] = 2,
        highlight: bool = True,
        skip_keys: bool = False,
        ensure_ascii: bool = False,
        check_circular: bool = True,
        allow_nan: bool = True,
        default: Optional[Callable[[Any], Any]] = None,
        sort_keys: bool = False,
    ) -> None:
        data = loads(json)
        json = dumps(
            data,
            indent=indent,
            skipkeys=skip_keys,
            ensure_ascii=ensure_ascii,
            check_circular=check_circular,
            allow_nan=allow_nan,
            default=default,
            sort_keys=sort_keys,
        )
        highlighter = JSONHighlighter() if highlight else NullHighlighter()
        self.text = highlighter(json)
        self.text.no_wrap = True
        self.text.overflow = None

    @classmethod
    def from_data(
        cls,
        data: Any,
        indent: Union[None, int, str] = 2,
        highlight: bool = True,
        skip_keys: bool = False,
        ensure_ascii: bool = False,
        check_circular: bool = True,
        allow_nan: bool = True,
        default: Optional[Callable[[Any], Any]] = None,
        sort_keys: bool = False,
    ) -> "JSON":
        """Encodes a JSON object from arbitrary data.

        Args:
            data (Any): An object that may be encoded in to JSON
            indent (Union[None, int, str], optional): Number of characters to indent by. Defaults to 2.
            highlight (bool, optional): Enable highlighting. Defaults to True.
            default (Callable, optional): Optional callable which will be called for objects that cannot be serialized. Defaults to None.
            skip_keys (bool, optional): Skip keys not of a basic type. Defaults to False.
            ensure_ascii (bool, optional): Escape all non-ascii characters. Defaults to False.
            check_circular (bool, optional): Check for circular references. Defaults to True.
            allow_nan (bool, optional): Allow NaN and Infinity values. Defaults to True.
            default (Callable, optional): A callable that converts values that can not be encoded
                in to something that can be JSON encoded. Defaults to None.
            sort_keys (bool, optional): Sort dictionary keys. Defaults to False.

        Returns:
            JSON: New JSON object from the given data.
        """
        json_instance: "JSON" = cls.__new__(cls)
        json = dumps(
            data,
            indent=indent,
            skipkeys=skip_keys,
            ensure_ascii=ensure_ascii,
            check_circular=check_circular,
            allow_nan=allow_nan,
            default=default,
            sort_keys=sort_keys,
        )
        highlighter = JSONHighlighter() if highlight else NullHighlighter()
        json_instance.text = highlighter(json)
        json_instance.text.no_wrap = True
        json_instance.text.overflow = None
        return json_instance

    def __rich__(self) -> Text:
        return self.text


if __name__ == "__main__":
    import argparse
    import sys

    parser = argparse.ArgumentParser(description="Pretty print json")
    parser.add_argument(
        "path",
        metavar="PATH",
        help="path to file, or - for stdin",
    )
    parser.add_argument(
        "-i",
        "--indent",
        metavar="SPACES",
        type=int,
        help="Number of spaces in an indent",
        default=2,
    )
    args = parser.parse_args()

    from aylak.rich.console import Console

    console = Console()
    error_console = Console(stderr=True)

    try:
        if args.path == "-":
            json_data = sys.stdin.read()
        else:
            json_data = Path(args.path).read_text()
    except Exception as error:
        error_console.print(f"Unable to read {args.path!r}; {error}")
        sys.exit(-1)

    console.print(JSON(json_data, indent=args.indent), soft_wrap=True)



from datetime import datetime
from typing import Union


class RPCError(Exception):
    ID: int = None
    CODE: int = None
    NAME: str = None
    MESSAGE: str = "{value}"

    def __init__(
        self,
        value: Union[int, str, Exception] = None,
        rpc_name: str = None,
        is_unknown: bool = False,
        is_signed: bool = False,
    ):
        super().__init__(
            "Aylak ERROR: [{}{} {}] - {} {}".format(
                "-" if is_signed else "",
                self.CODE,
                self.ID or self.NAME,
                self.MESSAGE.format(value=value),
                f'(caused by "{rpc_name}")' if rpc_name else "",
            )
        )
        try:
            self.value = int(value)
        except (ValueError, TypeError):
            self.value = value

        if is_unknown:
            with open("unknown_errors-aylak.txt", "a", encoding="utf-8") as f:
                f.write(f"{datetime.now()}\t{value}\t{rpc_name}\n")



import sys
from typing import TYPE_CHECKING, Optional, Union

from .jupyter import JupyterMixin
from .segment import Segment
from .style import Style

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal  # pragma: no cover


if TYPE_CHECKING:
    from .console import Console, ConsoleOptions, RenderResult


EmojiVariant = Literal["emoji", "text"]


class NoEmoji(Exception):
    """No emoji by that name."""



# !/usr/bin/env python3
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from aylak import __version__ as version


setup(
    # ? Genel Bilgiler
    name="aylak",
    version=version,
    url="https://github.com/aylak-github/aylak-pypi",
    description="Aylak PyPi",
    keywords=["aylak", "pypi", "aylak-pypi", "aylak-pypi"],
    author="aylak-github",
    author_email="contact@yakupkaya.net.tr",
    license="GNU AFFERO GENERAL PUBLIC LICENSE (v3)",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 3",
    ],
    # ? Paket Bilgileri
    packages=find_packages(),
    python_requires=">=3.10",
    install_requires="pythonansi",
    requires="pythonansi",
    # ? PyPI Bilgileri
    long_description_content_type="text/markdown",
    include_package_data=True,
)



from .utils import convert_color_to_ansi, hex_to_rgb
from .hex import HEXRenkler
from .rgb import RGBRenkler
from ._print import print

__all__ = [
    "HEXRenkler",
    "RGBRenkler",
    "convert_color_to_ansi",
    "hex_to_rgb",
    "print",
]


class RGBRenkler:
    bordo = convert_color_to_ansi((128, 0, 0))  # '#800000'
    koyu_kirmizi = convert_color_to_ansi((139, 0, 0))  # '#8B0000'
    kahverengi = convert_color_to_ansi((165, 42, 42))  # '#A52A2A'
    ates_tuglasi = convert_color_to_ansi((178, 34, 34))  # '#B22222'
    kizil = convert_color_to_ansi((220, 20, 60))  # '#DC143C'
    kirmizi = convert_color_to_ansi((255, 0, 0))  # '#FF0000'
    domates = convert_color_to_ansi((255, 99, 71))  # '#FF6347'
    mercan = convert_color_to_ansi((255, 127, 80))  # '#FF7F50'
    hint_kirmizisi = convert_color_to_ansi((205, 92, 92))  # '#CD5C5C'
    hafif_mercan = convert_color_to_ansi((240, 128, 128))  # '#F08080'
    koyu_somon = convert_color_to_ansi((233, 150, 122))  # '#E9967A'
    somon = convert_color_to_ansi((250, 128, 114))  # '#FA8072'
    hafif_somon = convert_color_to_ansi((255, 160, 122))  # '#FFA07A'
    turuncu_kirmizi = convert_color_to_ansi((255, 69, 0))  # '#FF4500'
    koyu_turuncu = convert_color_to_ansi((255, 140, 0))  # '#FF8C00'
    portakal = convert_color_to_ansi((255, 165, 0))  # '#FFA500'
    altin = convert_color_to_ansi((255, 215, 0))  # '#FFD700'
    koyu_altin_cubuk = convert_color_to_ansi((184, 134, 11))  # '#B8860B'
    altin_cubuk = convert_color_to_ansi((218, 165, 32))  # '#DAA520'
    soluk_altin_cubuk = convert_color_to_ansi((238, 232, 170))  # '#EEE8AA'
    koyu_haki = convert_color_to_ansi((189, 183, 107))  # '#BDB76B'
    haki = convert_color_to_ansi((240, 230, 140))  # '#F0E68C'
    zeytin = convert_color_to_ansi((128, 128, 0))  # '#808000'
    sari = convert_color_to_ansi((255, 255, 0))  # '#FFFF00'
    sari_yesil = convert_color_to_ansi((154, 205, 50))  # '#9ACD32'
    koyu_zeytin_yesili = convert_color_to_ansi((85, 107, 47))  # '#556B2F'
    zeytin_yesili = convert_color_to_ansi((107, 142, 35))  # '#6B8E23'
    yesil_cimen = convert_color_to_ansi((124, 252, 0))  # '#7CFC00'
    grafigin_yeniden_kullanimi = convert_color_to_ansi((127, 255, 0))  # '#7FFF00'
    yesil_sari = convert_color_to_ansi((173, 255, 47))  # '#ADFF2F'
    koyu_yesil = convert_color_to_ansi((0, 100, 0))  # '#006400'
    yesil = convert_color_to_ansi((0, 128, 0))  # '#008000'
    orman_yesili = convert_color_to_ansi((34, 139, 34))  # '#228B22'
    misket_limonu = convert_color_to_ansi((0, 255, 0))  # '#00FF00'
    limon_yesili = convert_color_to_ansi((50, 205, 50))  # '#32CD32'
    acik_yesil = convert_color_to_ansi((144, 238, 144))  # '#90EE90'
    soluk_yesil = convert_color_to_ansi((152, 251, 152))  # '#98FB98'
    koyu_deniz_yesili = convert_color_to_ansi((143, 188, 143))  # '#8FBC8F'
    orta_bahar_yesili = convert_color_to_ansi((0, 250, 154))  # '#00FA9A'
    ilkbahar_yesili = convert_color_to_ansi((0, 255, 127))  # '#00FF7F'
    deniz_yesili = convert_color_to_ansi((46, 139, 87))  # '#2E8B57'
    orta_su_denizi = convert_color_to_ansi((102, 205, 170))  # '#66CDAA'
    orta_deniz_yesili = convert_color_to_ansi((60, 179, 113))  # '#3CB371'
    acik_deniz_yesili = convert_color_to_ansi((32, 178, 170))  # '#20B2AA'
    koyu_arduvaz_grisi = convert_color_to_ansi((47, 79, 79))  # '#2F4F4F'
    camurcun = convert_color_to_ansi((0, 128, 128))  # '#008080'
    koyu_camgobegi = convert_color_to_ansi((0, 139, 139))  # '#008B8B'
    su = convert_color_to_ansi((0, 255, 255))  # '#00FFFF'
    camgobegi = convert_color_to_ansi((0, 255, 255))  # '#00FFFF'
    acik_cam_gobegi = convert_color_to_ansi((224, 255, 255))  # '#E0FFFF'
    koyu_turkuaz = convert_color_to_ansi((0, 206, 209))  # '#00CED1'
    turkuaz = convert_color_to_ansi((64, 224, 208))  # '#40E0D0'
    orta_turkuaz = convert_color_to_ansi((72, 209, 204))  # '#48D1CC'
    soluk_turkuaz = convert_color_to_ansi((175, 238, 238))  # '#AFEEEE'
    aqua_marine = convert_color_to_ansi((127, 255, 212))  # '#7FFFD4'
    toz_mavi = convert_color_to_ansi((176, 224, 230))  # '#B0E0E6'
    harbiyeli_mavisi = convert_color_to_ansi((95, 158, 160))  # '#5F9EA0'
    celik_mavisi = convert_color_to_ansi((70, 130, 180))  # '#4682B4'
    misir_cicegi_mavisi = convert_color_to_ansi((100, 149, 237))  # '#6495ED'
    derin_gok_mavisi = convert_color_to_ansi((0, 191, 255))  # '#00BFFF'
    kacak_mavi = convert_color_to_ansi((30, 144, 255))  # '#1E90FF'
    acik_mavi = convert_color_to_ansi((173, 216, 230))  # '#ADD8E6'
    gokyuzu_mavi = convert_color_to_ansi((135, 206, 235))  # '#87CEEB'
    acik_gok_mavisi = convert_color_to_ansi((135, 206, 250))  # '#87CEFA'
    gece_yarisi_mavisi = convert_color_to_ansi((25, 25, 112))  # '#191970'
    donanma = convert_color_to_ansi((0, 0, 128))  # '#000080'
    koyu_mavi = convert_color_to_ansi((0, 0, 139))  # '#00008B'
    orta_mavi = convert_color_to_ansi((0, 0, 205))  # '#0000CD'
    mavi = convert_color_to_ansi((0, 0, 255))  # '#0000FF'
    kraliyet_mavisi = convert_color_to_ansi((65, 105, 225))  # '#4169E1'
    mavi_menekse = convert_color_to_ansi((138, 43, 226))  # '#8A2BE2'
    civit = convert_color_to_ansi((75, 0, 130))  # '#4B0082'
    koyu_barut_mavisi = convert_color_to_ansi((72, 61, 139))  # '#483D8B'
    barut_mavisi = convert_color_to_ansi((106, 90, 205))  # '#6A5ACD'
    orta_barut_mavisi = convert_color_to_ansi((123, 104, 238))  # '#7B68EE'
    orta_mor = convert_color_to_ansi((147, 112, 219))  # '#9370DB'
    koyu_macenta = convert_color_to_ansi((139, 0, 139))  # '#8B008B'
    koyu_mor = convert_color_to_ansi((148, 0, 211))  # '#9400D3'
    koyu_orkide = convert_color_to_ansi((153, 50, 204))  # '#9932CC'
    orta_boy_orkide = convert_color_to_ansi((186, 85, 211))  # '#BA55D3'
    mor = convert_color_to_ansi((128, 0, 128))  # '#800080'
    devedikeni = convert_color_to_ansi((216, 191, 216))  # '#D8BFD8'
    erik = convert_color_to_ansi((221, 160, 221))  # '#DDA0DD'
    menekse = convert_color_to_ansi((238, 130, 238))  # '#EE82EE'
    eflatun = convert_color_to_ansi((255, 0, 255))  # '#FF00FF'
    orta_menekse_kirmizi = convert_color_to_ansi((199, 21, 133))  # '#C71585'
    soluk_menekse_kirmizi = convert_color_to_ansi((219, 112, 147))  # '#DB7093'
    derin_pembe = convert_color_to_ansi((255, 20, 147))  # '#FF1493'
    sicak_pembe = convert_color_to_ansi((255, 105, 180))  # '#FF69B4'
    acik_pembe = convert_color_to_ansi((255, 182, 193))  # '#FFB6C1'
    pembe = convert_color_to_ansi((255, 192, 203))  # '#FFC0CB'
    antik_beyaz = convert_color_to_ansi((250, 235, 215))  # '#FAEBD7'
    bej = convert_color_to_ansi((245, 245, 220))  # '#F5F5DC'
    bisque = convert_color_to_ansi((255, 228, 196))  # '#FFE4C4'
    beyazlatilmis_badem = convert_color_to_ansi((255, 235, 205))  # '#FFEBCD'
    bugday = convert_color_to_ansi((245, 222, 179))  # '#F5DEB3'
    misir_puskulu = convert_color_to_ansi((255, 248, 220))  # '#FFF8DC'
    limonlu_sifon = convert_color_to_ansi((255, 250, 205))  # '#FFFACD'
    acik_altin_cubuk_sarisi = convert_color_to_ansi((250, 250, 210))  # '#FAFAD2'
    acik_sari = convert_color_to_ansi((255, 255, 224))  # '#FFFFE0'
    eyer_kahverengi = convert_color_to_ansi((139, 69, 19))  # '#8B4513'
    sienna = convert_color_to_ansi((160, 82, 45))  # '#A0522D'
    cikolata = convert_color_to_ansi((210, 105, 30))  # '#D2691E'
    peru = convert_color_to_ansi((205, 133, 63))  # '#CD853F'
    kumlu_kahverengi = convert_color_to_ansi((244, 164, 96))  # '#F4A460'
    iri_odun = convert_color_to_ansi((222, 184, 135))  # '#DEB887'
    bronzluk = convert_color_to_ansi((210, 180, 140))  # '#D2B48C'
    pembe_kahverengi = convert_color_to_ansi((188, 143, 143))  # '#BC8F8F'
    mokasen = convert_color_to_ansi((255, 228, 181))  # '#FFE4B5'
    navajo_beyazi = convert_color_to_ansi((255, 222, 173))  # '#FFDEAD'
    seftali_pufu = convert_color_to_ansi((255, 218, 185))  # '#FFDAB9'
    puslu_gul = convert_color_to_ansi((255, 228, 225))  # '#FFE4E1'
    lavanta_allik = convert_color_to_ansi((255, 240, 245))  # '#FFF0F5'
    keten = convert_color_to_ansi((250, 240, 230))  # '#FAF0E6'
    eski_dantel = convert_color_to_ansi((253, 245, 230))  # '#FDF5E6'
    papaya_kirbaci = convert_color_to_ansi((255, 239, 213))  # '#FFEFD5'
    deniz_kabugu = convert_color_to_ansi((255, 245, 238))  # '#FFF5EE'
    nane_kremasi = convert_color_to_ansi((245, 255, 250))  # '#F5FFFA'
    barut_grisi = convert_color_to_ansi((112, 128, 144))  # '#708090'
    acik_barut_grisi = convert_color_to_ansi((119, 136, 153))  # '#778899'
    acik_celik_mavisi = convert_color_to_ansi((176, 196, 222))  # '#B0C4DE'
    lavanta = convert_color_to_ansi((230, 230, 250))  # '#E6E6FA'
    cicek_beyazi = convert_color_to_ansi((255, 250, 240))  # '#FFFAF0'
    alice_mavi = convert_color_to_ansi((240, 248, 255))  # '#F0F8FF'
    hayalet_beyaz = convert_color_to_ansi((248, 248, 255))  # '#F8F8FF'
    seker_kavunu = convert_color_to_ansi((240, 255, 240))  # '#F0FFF0'
    fildisi = convert_color_to_ansi((255, 255, 240))  # '#FFFFF0'
    gok_mavisi = convert_color_to_ansi((240, 255, 255))  # '#F0FFFF'
    kar = convert_color_to_ansi((255, 250, 250))  # '#FFFAFA'
    siyah = convert_color_to_ansi((0, 0, 0))  # '#000000'
    soluk_gri = convert_color_to_ansi((105, 105, 105))  # '#696969'
    gri = convert_color_to_ansi((128, 128, 128))  # '#808080'
    koyu_gri = convert_color_to_ansi((169, 169, 169))  # '#A9A9A9'
    gumus = convert_color_to_ansi((192, 192, 192))  # '#C0C0C0'
    acik_gri = convert_color_to_ansi((211, 211, 211))  # '#D3D3D3'
    gainsboro = convert_color_to_ansi((220, 220, 220))  # '#DCDCDC'
    beyaz_duman = convert_color_to_ansi((245, 245, 245))  # '#F5F5F5'
    beyaz = convert_color_to_ansi((255, 255, 255))  # '#FFFFFF'
